==> digikamimageplugins-0.7.4.tar.bz2: digikamimageplugins-0.7.4/digikamimageplugins/common/include/digikamheaders.h <==
/* ============================================================
 * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
 * Date  : 2004-12-22
 * Copyright 2004 by Renchi Raju
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * ============================================================ */

#ifndef DIGIKAMHEADERS_H
#define DIGIKAMHEADERS_H

#include <config.h>

#ifdef HAVE_DIGIKAM_TOPLEVEL

#include <colorgradientwidget.h>
#include <histogramwidget.h>
#include <curveswidget.h>
#include <imagecurves.h>
#include <imagehistogram.h>
#include <imagefilters.h>
#include <imageiface.h>
#include <imagelevels.h>
#include <imagepaniconwidget.h>
#include <imageplugin.h>
#include <imagepreviewwidget.h>
#include <imageregionwidget.h>
#include <imageselectionwidget.h>
#include <imageguidewidget.h>
#include <imagewidget.h>
#include <thumbbar.h>

#else

#include <digikam/colorgradientwidget.h>
#include <digikam/histogramwidget.h>
#include <digikam/curveswidget.h>
#include <digikam/imagecurves.h>
#include <digikam/imagehistogram.h>
#include <digikam/imagefilters.h>
#include <digikam/imageiface.h>
#include <digikam/imagelevels.h>
#include <digikam/imagepaniconwidget.h>
#include <digikam/imageplugin.h>
#include <digikam/imagepreviewwidget.h>
#include <digikam/imageregionwidget.h>
#include <digikam/imageselectionwidget.h>
#include <digikam/imageguidewidget.h>
#include <digikam/imagewidget.h>
#include <digikam/thumbbar.h>

#endif

#endif /* DIGIKAMHEADERS_H */

==> digikamimageplugins-0.8.1.tar.bz2: digikamimageplugins-0.8.1/digikamimageplugins/common/include/digikamheaders.h <==
/* ============================================================
 * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
 * Date  : 2004-12-22
 * Copyright 2004 by Renchi Raju
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * ============================================================ */

#ifndef DIGIKAMHEADERS_H
#define DIGIKAMHEADERS_H

#include <config.h>

#ifdef HAVE_DIGIKAM_TOPLEVEL

#include <colorgradientwidget.h>
#include <histogramwidget.h>
#include <curveswidget.h>
#include <imagecurves.h>
#include <imagehistogram.h>
#include <imagefilters.h>
#include <threadedfilter.h>
#include <imageiface.h>
#include <imagelevels.h>
#include <imagepaniconwidget.h>
#include <imageplugin.h>
#include <imagepannelwidget.h>
#include <imageregionwidget.h>
#include <imageselectionwidget.h>
#include <imageguidewidget.h>
#include <imagewidget.h>
#include <thumbbar.h>

#else

#include <digikam/colorgradientwidget.h>
#include <digikam/histogramwidget.h>
#include <digikam/curveswidget.h>
#include <digikam/imagecurves.h>
#include <digikam/imagehistogram.h>
#include <digikam/imagefilters.h>
#include <digikam/threadedfilter.h>
#include <digikam/imageiface.h>
#include <digikam/imagelevels.h>
#include <digikam/imagepaniconwidget.h>
#include <digikam/imageplugin.h>
#include <digikam/imagepannelwidget.h>
#include <digikam/imageregionwidget.h>
#include <digikam/imageselectionwidget.h>
#include <digikam/imageguidewidget.h>
#include <digikam/imagewidget.h>
#include <digikam/thumbbar.h>

#endif

#endif /* DIGIKAMHEADERS_H */
